==> s-component-ui-1.0.5.tgz: package/es/index/index.es.js <==
import { defineComponent as m, computed as b, openBlock as p, createElementBlock as z, normalizeClass as _, unref as a, normalizeStyle as f, renderSlot as w, createApp as $, h } from "vue";
function r(n, t, s, e) {
  return t && (n += `-${t}`), s && (n += `__${s}`), e && (n += `--${e}`), n;
}
function y(n) {
  return {
    b: (o = "") => r(n, o, "", ""),
    e: (o = "") => o ? r(n, "", o, "") : "",
    m: (o = "") => o ? r(n, "", "", o) : "",
    be: (o = "", c = "") => o && c ? r(n, o, c, "") : "",
    bm: (o = "", c = "") => o && c ? r(n, o, "", c) : "",
    em: (o = "", c = "") => o && c ? r(n, "", o, c) : "",
    bem: (o = "", c = "", l = "") => o && c && l ? r(n, o, c, l) : "",
    is: (o, c) => c ? `is-${o}` : ""
  };
}
function g(n) {
  const t = `z-${n}`;
  return y(t);
}
const C = {
  color: String,
  size: [Number, String]
}, E = /* @__PURE__ */ m({
  __name: "icon",
  props: C,
  setup(n) {
    const t = n;
    defineOptions({
      name: "s-icon"
    });
    const s = g("icon"), e = b(() => !t.size && !t.color ? {} : {
      ...t.size ? { "font-size": t.size + "px" } : {},
      ...t.color ? { color: t.color } : {}
    });
    return (u, d) => (p(), z("i", {
      class: _(a(s).b()),
      style: f(a(e))
    }, [
      w(u.$slots, "default")
    ], 6));
  }
});
function B(n) {
  const t = $(n), s = document.createElement("div");
  return document.body.appendChild(s), {
    instance: t.mount(s),
    unmount() {
      t.unmount(), document.body.removeChild(s);
    }
  };
}
function I(n) {
  return (t = {}) => {
    const { unmount: s } = B({
      setup() {
        const e = {
          dialogVisible: !0,
          close: () => {
            s();
          }
        };
        return () => h(n, { ...e, ...t });
      }
    });
  };
}
function V(n, t = !1, s) {
  return n.install = (e) => {
    const { name: u } = n;
    u && (s = u), e.component(s, n), t && (e.config.globalProperties["$" + s] = I(n));
  }, n;
}
const v = V(E), P = [v], i = function(n) {
  i.installed || (i.installed = !0, P.forEach((t) => {
    n.use(t);
  }));
};
typeof window < "u" && window.Vue && i(window.Vue);
export {
  i as default,
  C as iconProps
};

==> s-component-ui-1.0.6.tgz: package/es/index/index.es.js <==
import { defineComponent as m, computed as b, openBlock as p, createElementBlock as z, normalizeClass as _, unref as a, normalizeStyle as f, renderSlot as w, createApp as $, h } from "vue";
function r(n, t, s, e) {
  return t && (n += `-${t}`), s && (n += `__${s}`), e && (n += `--${e}`), n;
}
function y(n) {
  return {
    b: (o = "") => r(n, o, "", ""),
    e: (o = "") => o ? r(n, "", o, "") : "",
    m: (o = "") => o ? r(n, "", "", o) : "",
    be: (o = "", c = "") => o && c ? r(n, o, c, "") : "",
    bm: (o = "", c = "") => o && c ? r(n, o, "", c) : "",
    em: (o = "", c = "") => o && c ? r(n, "", o, c) : "",
    bem: (o = "", c = "", i = "") => o && c && i ? r(n, o, c, i) : "",
    is: (o, c) => c ? `is-${o}` : ""
  };
}
function g(n) {
  const t = `z-${n}`;
  return y(t);
}
const C = {
  color: String,
  size: [Number, String]
}, E = /* @__PURE__ */ m({
  __name: "icon",
  props: C,
  setup(n) {
    const t = n, s = g("icon"), e = b(() => !t.size && !t.color ? {} : {
      ...t.size ? { "font-size": t.size + "px" } : {},
      ...t.color ? { color: t.color } : {}
    });
    return (u, d) => (p(), z("i", {
      class: _(a(s).b()),
      style: f(a(e))
    }, [
      w(u.$slots, "default")
    ], 6));
  }
});
function B(n) {
  const t = $(n), s = document.createElement("div");
  return document.body.appendChild(s), {
    instance: t.mount(s),
    unmount() {
      t.unmount(), document.body.removeChild(s);
    }
  };
}
function I(n) {
  return (t = {}) => {
    const { unmount: s } = B({
      setup() {
        const e = {
          dialogVisible: !0,
          close: () => {
            s();
          }
        };
        return () => h(n, { ...e, ...t });
      }
    });
  };
}
function V(n, t = !1, s) {
  return n.install = (e) => {
    const { name: u } = n;
    u && (s = u), e.component(s, n), t && (e.config.globalProperties["$" + s] = I(n));
  }, n;
}
const v = V(E, !1, "s-icon"), P = [v], l = function(n) {
  l.installed || (l.installed = !0, P.forEach((t) => {
    n.use(t);
  }));
};
typeof window < "u" && window.Vue && l(window.Vue);
export {
  l as default,
  C as iconProps
};
